@@ -35,7 +35,7 @@ class Task(irisml.core.TaskBase):
 
     @dataclasses.dataclass
     class Outputs:
-        model: torch.nn.Module = None
+        model: torch.nn.Module
 
     def execute(self, inputs: Inputs):
         num_sources = len([x for x in [inputs.state_dict, inputs.state_dict_bytes, self.config.path] if x])
@@ -58,10 +58,14 @@ class Task(irisml.core.TaskBase):
             new_state_dict = {k: v for k, v in state_dict.items() if k in existing_state_dict and v.shape == existing_state_dict[k].shape}
 
             ignored_keys = set(state_dict) - set(new_state_dict)
-            logger.info(f"Ignored {ignored_keys} since they have different shapes.")
+            if ignored_keys:
+                logger.info(f"Ignored {ignored_keys} since they are redundant or they have different shapes.")
 
             state_dict = new_state_dict
 
         model = copy.deepcopy(inputs.model)
         model.load_state_dict(state_dict, strict=self.config.strict)
         return self.Outputs(model)
+
+    def dry_run(self, inputs):
+        return self.Outputs(inputs.model)
